========================
Team and repository tags
========================

.. image:: https://governance.openstack.org/tc/badges/python-freezerclient.svg
    :target: https://governance.openstack.org/tc/reference/tags/index.html

.. Change things from this point on

=============================================================
Python bindings to the OpenStack Backup/Restore API (Freezer)
=============================================================

.. image:: https://img.shields.io/pypi/v/python-freezerclient.svg
    :target: https://pypi.org/project/python-freezerclient/
    :alt: Latest Version

This is a client library for Freezer built on the OpenStack Disaster Recovery API. It provides a Python API (the freezerclient module) and a command-line tool (freezer). This library fully supports the v1 Disaster Recovery API.

Development takes place via the usual OpenStack processes as outlined in the `developer guide <https://docs.openstack.org/infra/manual/developers.html>`_.  The master repository is in `Git <https://opendev.org/openstack/python-freezerclient>`_.


* License: Apache License, Version 2.0
* `PyPi`_ - package installation
* `Online Documentation`_
* `Launchpad project`_ - release management
* `Blueprints`_ - feature specifications
* `Bugs`_ - issue tracking
* `Source`_
* `How to Contribute`_

.. _PyPi: https://pypi.org/project/python-freezerclient
.. _Online Documentation: https://wiki.openstack.org/wiki/Python-freezerclient
.. _Launchpad project: https://launchpad.net/python-freezerclient
.. _Blueprints: https://blueprints.launchpad.net/python-freezerclient
.. _Bugs: https://storyboard.openstack.org/#!/project/openstack/python-freezerclient
.. _Source: https://opendev.org/openstack/python-freezerclient
.. _How to Contribute: https://docs.openstack.org/infra/manual/developers.html
.. _Release notes: https://docs.openstack.org/releasenotes/python-freezerclient/
